<?php

namespace Drupal\block_class\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Form for Block Class Settings.
 */
class BlockClassSettingsForm extends ConfigFormBase {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'block_class_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'block_class.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $config = $this->config('block_class.settings');

    $form['global_settings'] = [
      '#type' => 'details',
      '#title' => $this->t('Global Settings'),
      '#open' => TRUE,
    ];

    // Default value.
    $default_case = 'standard';

    // Verify if there is a value in the database.
    if (!empty($config->get('default_case'))) {
      $default_case = $config->get('default_case');
    }

    $form['global_settings']['default_case'] = [
      '#title' => $this->t("Default Case"),
      '#type' => 'select',
      '#description' => $this->t('If you select "Uppercase and Lowercase" but cases will be accepted. If you select "Uppercase" all classes will be added using uppercase and if you select "Lowercase" all classes added will be added using lowercase.'),
      '#options' => [
        'standard' => $this->t('Uppercase and Lowercase (Standard)'),
        'uppercase' => $this->t('Uppercase'),
        'lowercase' => $this->t('Lowercase'),
      ],
      '#default_value' => $default_case,
    ];

    $field_type = 'textfield';

    if (!empty($config->get('field_type'))) {
      $field_type = $config->get('field_type');
    }

    $form['global_settings']['field_type'] = [
      '#title' => $this->t("Field Type"),
      '#type' => 'select',
      '#options' => [
        'textfield' => $this->t('textfield'),
        'textarea' => $this->t('textarea'),
      ],
      '#default_value' => $field_type,
    ];

    $maxlength_block_class_field = 255;

    if (!empty($config->get('maxlength_block_class_field'))) {
      $maxlength_block_class_field = $config->get('maxlength_block_class_field');
    }

    $form['global_settings']['maxlength_block_class_field'] = [
      '#title' => $this->t("Maxlength on block class field"),
      '#type' => 'number',
      '#description' => $this->t('This will be the default maxlength value for the "maxlength" field. The default is 255.'),
      '#default_value' => $maxlength_block_class_field,
    ];

    $form['global_settings']['allow_only_letters_and_numbers'] = [
      '#title' => $this->t("Allow only letters and numbers"),
      '#type' => 'checkbox',
      '#description' => $this->t('If selected the classes will allows only letters and numbers and will remove special chars.'),
      '#default_value' => $config->get('allow_only_letters_and_numbers'),
    ];

    $form['actions'] = [
      '#type' => 'actions',
    ];

    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
    ];

    return $form;

  }

  /**
   * Validate the maxlength field.
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

    parent::validateForm($form, $form_state);

    // Get the maxlength_block_class_field field.
    $maxlength_block_class_field = $form_state->getValue('maxlength_block_class_field');

    // Verify if is a positive value.
    if ($maxlength_block_class_field < 1) {
      $form_state->setErrorByName('maxlength_block_class_field', $this->t('The maxlength should be an positive value'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    // Get the default case.
    $default_case = $form_state->getValue('default_case');

    // Get the field type.
    $field_type = $form_state->getValue('field_type');

    // Get the maxlength_block_class_field field.
    $maxlength_block_class_field = $form_state->getValue('maxlength_block_class_field');

    $allow_only_letters_and_numbers = $form_state->getValue('allow_only_letters_and_numbers');

    // Get the config object.
    $config = $this->config('block_class.settings');

    if (($config->get('default_case') != $default_case) && ($default_case == 'uppercase' || $default_case == 'lowercase')) {

      // Put warning messages updating case type only when is updating to a different one.
      switch ($default_case) {

        case 'uppercase':

          $warning_message_case = $this->t('When selecting "Uppercase" when saving a block, your classes will be saved as uppercase');

          break;

        case 'lowercase':

          $warning_message_case = $this->t('When selecting "Lowercase" when saving a block, your classes will be saved as lowercase');

          break;

      }

      // Show the message on submit.
      \Drupal::messenger()->addWarning($warning_message_case);
    }

    // Set the values.
    $config->set('default_case', $default_case);
    $config->set('field_type', $field_type);
    $config->set('maxlength_block_class_field', $maxlength_block_class_field);
    $config->set('allow_only_letters_and_numbers', $allow_only_letters_and_numbers);

    // Save that.
    $config->save();

    parent::submitForm($form, $form_state);
  }

}
